==> switch_theme-1.0.0.tar.gz: switch_theme/src/SwitchthemeManager.php <==
<?php

namespace Drupal\switch_theme;

use Drupal\Core\Database\Connection;

/**
 * switch theme manager
 */
class SwitchthemeManager implements SwitchthemeManagerInterface {
  /**
   * Database connection
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;
 
  /**
   * @var \Drupal\Core\Database\Connection
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }
  
  /**
   * Get Switch themes
   * 
   * @return array
   */
  public function getSwitchThemes() {
   
    $query = $this->connection->select('switch_theme', 's');
    $query->innerJoin('switch_theme_role', 'sr', 's.id = sr.switch_theme_id');
    $query->innerJoin('switch_theme_pattern', 'sp', 's.id = sp.switch_theme_id');
    $query->innerJoin('switch_theme_theme', 'st', 's.id = st.switch_theme_id'); 
    $query->addExpression('GROUP_CONCAT(sr.role_code)', 'roles');
    $query->fields('s', ['id']);
    $query->fields('sp', ['pattern']);
    $query->fields('st', ['theme_code']);
    $query->groupBy('s.id, sp.pattern, st.theme_code');
    $results = $query->execute()
      ->fetchAll();
     
    $return = [];
    foreach ($results as $result) {
      $return[] = [
          'pattern'     => $result->pattern,
          'theme_code'  => $result->theme_code,
          'roles'       => explode(',', $result->roles),
      ];
    }

    return $return;  
  }

  /**
   * Get item
   * 
   * @param int $id
   *
   * @return \stdClass|null
   */
  public function getItem($id) {

    $query = $this->connection->select('switch_theme', 's');
    $query->fields('s', ['name']);
    $query->innerJoin('switch_theme_pattern', 'sp', 's.id = sp.switch_theme_id');
    $query->innerJoin('switch_theme_theme', 'st', 's.id = st.switch_theme_id'); 
    $query->fields('sp', ['pattern']);
    $query->fields('st', ['theme_code']);
    $query->condition('s.id', $id, "=");
    return $query->execute()
        ->fetchAll()[0];
  }

  /**
   * Get selected roles
   *
   * @param int $id
   * 
   * @return array
   */
  public function getSelectedRoles($id) {

      $roles = [];

      $items = $this->connection->select('switch_theme_role')
          ->fields('switch_theme_role', ['role_code'])
          ->condition('switch_theme_id', $id, "=")
          ->execute()
          ->fetchAll();
       
      foreach ($items as $item) {
          $roles[] = $item->role_code;
      }

      return $roles;
  }
}

==> switch_theme-1.1.0.tar.gz: switch_theme/src/SwitchthemeManager.php <==
<?php

namespace Drupal\switch_theme;

use Drupal\Core\Database\Connection;

/**
 * Switch theme manager
 */
class SwitchthemeManager implements SwitchthemeManagerInterface {
  
  /**
   * Database connection
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;
 
  /**
   * @var \Drupal\Core\Database\Connection
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }
  
  /**
   * Get Switch themes
   * 
   * @return array
   */
  public function getSwitchThemes() {

    $query = $this->connection->select('switch_theme', 's');
    $query->innerJoin('switch_theme_role', 'sr', 's.id = sr.switch_theme_id');
    $query->innerJoin('switch_theme_pattern', 'sp', 's.id = sp.switch_theme_id');
    $query->innerJoin('switch_theme_theme', 'st', 's.id = st.switch_theme_id');
    $query->fields('s', ['id']);
    $query->fields('sp', ['pattern']);
    $query->fields('st', ['theme_code']);
    $query->fields('sr', ['role_code']);

    $results = $query->execute()
      ->fetchAll();
     
    $return = [];
    foreach ($results as $result) {
      $return[] = [
          'pattern'     => $result->pattern,
          'theme_code'  => $result->theme_code,
          'role_code'   => $result->role_code,
      ];
    }

    return $return;  
  }

  /**
   * Get item
   * 
   * @param int Switch theme id $id
   *
   * @return \stdClass|null
   */
  public function getItem($id) {

    $query = $this->connection->select('switch_theme', 's');
    $query->fields('s', ['name']);
    $query->innerJoin('switch_theme_pattern', 'sp', 's.id = sp.switch_theme_id');
    $query->innerJoin('switch_theme_theme', 'st', 's.id = st.switch_theme_id'); 
    $query->fields('sp', ['pattern']);
    $query->fields('st', ['theme_code']);
    $query->condition('s.id', (int) $id, "=");
    return $query->execute()
        ->fetchObject();
  }

  /**
   * Get selected roles
   *
   * @param int Switch theme id $id
   * 
   * @return array
   */
  public function getSelectedRole($id) {

      return $this->connection->select('switch_theme_role')
          ->fields('switch_theme_role', ['role_code'])
          ->condition('switch_theme_id', (int) $id, "=")
          ->execute()
          ->fetchObject();
  }
}
